@@ -2,7 +2,7 @@ from django.db import models
 from django.contrib.auth.models import User
 
 
-class Post(models.Model):
+class AbstractPost(models.Model):
     author = models.ForeignKey(User, editable=False)
     headline = models.CharField(max_length=255)
     text = models.TextField()
@@ -10,10 +10,15 @@ class Post(models.Model):
 
     class Meta:
         ordering = ['-creation_date']
+        abstract = True
 
     def __unicode__(self):
         return self.headline
 
+
+class Post(AbstractPost):
+    pass
+
 class PositionPostMixin(models.Model):
     position = models.IntegerField()
 
